@@ -426,7 +426,8 @@ Ext.define('MP.data.MetaData', {
                 Ext.apply(editor, {
                     xtype: 'combo',
                     store: store,
-                    triggerAction: 'all'
+                    triggerAction: 'all',
+                    allowBlank: nullable
                 });
             } else if(info.lookup) {
                 var lup = info.lookup;
